@@ -84,6 +84,7 @@ register_cfunctions(lua_State *lua)
 	lua_register(lua, "set_window_position", c_set_window_position);
 	lua_register(lua, "set_window_position2", c_set_window_position2);
 	lua_register(lua, "set_window_size", c_set_window_size);
+	lua_register(lua, "set_window_strut", c_set_window_strut);
 
 	lua_register(lua, "set_window_geometry", c_set_window_geometry);
 	lua_register(lua, "set_window_geometry2", c_set_window_geometry2);
@@ -101,6 +102,7 @@ register_cfunctions(lua_State *lua)
 
 	lua_register(lua, "maximize", c_maximize_window);
 	lua_register(lua, "maximize_horisontally", c_maximize_window_horisontally);
+	lua_register(lua, "maximize_horizontally", c_maximize_window_horisontally);
 	lua_register(lua, "maximize_vertically", c_maximize_window_vertically);
 	lua_register(lua, "unmaximize", c_unmaximize_window);
 
@@ -119,6 +121,8 @@ register_cfunctions(lua_State *lua)
 	lua_register(lua, "stick_window", c_stick_window);
 	lua_register(lua, "unstick_window", c_unstick_window);
 
+	lua_register(lua, "close_window", c_close_window);
+
 	lua_register(lua, "get_window_geometry", c_get_window_geometry);
 	lua_register(lua, "get_window_client_geometry", c_get_client_window_geometry);
 
@@ -132,6 +136,8 @@ register_cfunctions(lua_State *lua)
 
 	lua_register(lua, "get_window_is_maximized_horisontally",
 		c_get_window_is_maximized_horisontally);
+	lua_register(lua, "get_window_is_maximized_horizontally",
+		c_get_window_is_maximized_horisontally);
 
 	lua_register(lua, "set_window_below", c_set_window_below);
 	lua_register(lua, "set_window_above", c_set_window_above);
@@ -148,17 +154,25 @@ register_cfunctions(lua_State *lua)
 	lua_register(lua, "set_viewport", c_set_viewport);
 
 	lua_register(lua, "center", c_center);
-	
+
 	lua_register(lua, "set_opacity", c_set_opacity);
+	lua_register(lua, "set_window_opacity", c_set_opacity);
+
 	lua_register(lua, "set_window_type", c_set_window_type);
 
 	lua_register(lua, "get_screen_geometry", c_get_screen_geometry);
+	
+	lua_register(lua, "get_window_fullscreen", c_get_window_fullscreen);
+	lua_register(lua, "get_fullscreen", c_get_window_fullscreen);
 
 #ifdef HAVE_GTK3
 	// wnck_window_get_class_instance_name is only availible on wnck 3 and later
 	lua_register(lua, "get_class_instance_name",c_get_class_instance_name);
 #endif
 
+	lua_register(lua, "focus", c_focus);
+	lua_register(lua, "focus_window", c_focus);
+
 }
 
 
